@@ -4,12 +4,17 @@ from pathlib import Path
 from typing import Dict, List, Any
 
 from threedi_api_client.openapi.models import Simulation
-from threedi_api_client.openapi.models import Schematisation
+from threedi_api_client.openapi.models import Schematisation, ThreediModel
 from threedi_api_client.openapi.api import V3Api
 from threedi_api_client.openapi.exceptions import ApiException
 from threedi_api_client.threedi_api_client import ThreediApiClient
 
-from .base import SimulationWrapper, ModelWrapper, BaseWrapper
+from .base import (
+    SimulationWrapper,
+    ModelWrapper,
+    BaseWrapper,
+    SimulationTemplateWrapper,
+)
 from .base import SchematisationWrapper
 from threedi_cmd.console import console
 from threedi_cmd.websockets.clients import WebsocketClient
@@ -39,12 +44,14 @@ class Scenario:
         wrappers: List[BaseWrapper],
         websocket_settings: WebSocketSettings,
         base_path: Path = None,
+        context: Dict = None,
     ):
         self._refs = {}
         self.wrappers = wrappers
         self.websocket_settings = websocket_settings
         self.threedi_api_client = threedi_api_client
         self._base_path = base_path
+        self.context = context
         scenario = data.get("scenario")
         if not scenario:
             raise LoadScenarioError("Could not load scenario")
@@ -166,13 +173,38 @@ class SimulationScenario(Scenario):
             pass
 
     def create_base_object(self, scenario: Dict):
+
         simulation_data = scenario.get("simulation")
+        threedimodel: ThreediModel = self.context["threedimodel"]
+
         if "tags" not in simulation_data:
             simulation_data["tags"] = ["automatic-test"]
         elif "automatic-test" not in simulation_data.get("tags", []):
             simulation_data["tags"].append("automatic-test")
 
-        self.base_object = SimulationWrapper(simulation_data, self.threedi_api_client)
+        if threedimodel.schematisation_id is not None:
+            # New threedimodel, use simulation template...
+            self.threedi_api_client: V3Api
+            templates = self.threedi_api_client.simulation_templates_list(
+                simulation__threedimodel__id=threedimodel.id
+            )
+
+            if templates.count < 0:
+                raise Exception(
+                    "No templates found for threedimodel: %s", threedimodel.id
+                )
+
+            # Inject into simulation_data
+            simulation_data["template"] = templates.results[0].id
+
+            self.base_object = SimulationTemplateWrapper(
+                simulation_data, self.threedi_api_client
+            )
+            self.base_object.save()
+        else:
+            self.base_object = SimulationWrapper(
+                simulation_data, self.threedi_api_client
+            )
 
     @property
     def websocket_endpoint_uri(self):
